RequestProgressUpdate class

Constructors

RequestProgressUpdate({required int? count, required int? total, required RequestProgressDirection direction, required Uri uri})
const

Properties

count int?
final
direction RequestProgressDirection
final
fraction double?
no setter
hashCode int
The hash code for this object.
no setterinherited
isComplete bool
no setter
isIndeterminate bool
no setter
percentage int?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
total int?
final
uri Uri
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited