RequestDioOptions class
Constructors
- RequestDioOptions({Duration? connectTimeout, Duration? receiveTimeout, Duration? sendTimeout, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress, Options? options})
-
const
- RequestDioOptions.stream({Duration? connectTimeout, Duration? receiveTimeout, Duration? sendTimeout, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress})
Properties
- cancelToken → CancelToken?
-
final
- connectTimeout → Duration?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- onReceiveProgress → ProgressCallback?
-
final
- onSendProgress → ProgressCallback?
-
final
- options → Options?
-
final
- receiveTimeout → Duration?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sendTimeout → Duration?
-
final
Methods
-
copyWith(
{Duration? connectTimeout, Duration? receiveTimeout, Duration? sendTimeout, CancelToken? cancelToken, ProgressCallback? onSendProgress, ProgressCallback? onReceiveProgress, Options? options}) → RequestDioOptions -
mergeWith(
Options base) → Options -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited