PreparedRequest class

Constructors

PreparedRequest({required String url, required Map<String, dynamic>? queryParameters, required dynamic data, required Options options, required CancelToken? cancelToken, required RequestDioOptions? dioOptions})
const

Properties

cancelToken → CancelToken?
final
data → dynamic
final
dioOptions RequestDioOptions?
final
hashCode int
The hash code for this object.
no setterinherited
options → Options
final
queryParameters Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
url String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onReceiveProgress(int received, int total, RequestApi requestApi) → void
onSendProgress(int sent, int total, RequestApi requestApi) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited